/**
   EpgScheduler - Automatic schedule of WinTV recordings via tvtv.de EPG
   Copyright (C) 2002 Steffen Siebert <siebert@SteffenSiebert.de>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package de.steffensiebert.epgscheduler;

import de.steffensiebert.jwindowsscheduler.WindowsTaskTriggerOnce;
import java.util.Calendar;

/**
 * WinTV schedules its tasks with one TASK_TIME_TRIGGER_ONCE tigger.
 * But it also sets the values for endYear, endMonth, endDay and
 * minutesDuration to remember the running time.
 *
 * This class mimics this behavior.
 */
class EpgTriggerOnce extends WindowsTaskTriggerOnce {
  public EpgTriggerOnce(Calendar start, Calendar end) {
    super(start.get(Calendar.DAY_OF_MONTH),
          start.get(Calendar.MONTH)+1,
          start.get(Calendar.YEAR),
          start.get(Calendar.HOUR_OF_DAY),
          start.get(Calendar.MINUTE));
    setEndYear(end.get(Calendar.YEAR));
    setEndMonth(end.get(Calendar.MONTH)+1);
    setEndDay(end.get(Calendar.DAY_OF_MONTH));
    long runtime = end.getTime().getTime() - start.getTime().getTime();
    setMinutesDuration((int) runtime/(60*1000));
  }

  public String toString() {
    return "Runs: "+getBeginDay()+"."+getBeginMonth()+"."+getBeginYear()+" "+getStartHour()+":"+getStartMinute()+" "+getMinutesDuration()+"min running time";
  }
}
